@@ -4,4 +4,4 @@ from .hello_world import HelloWorld
 from .nc_slicer import NetCDFSlicer
 from .ospray_studio import OSPRayStudio
 from .tapestry import Tapestry
-from .vci import VCI
+from .braid import Braid
